ozi-fix webui

### {TRANSLATION('adm-disclaimer-title')}

×

{disclaimer_text}

### {TRANSLATION('btn-options')}

×

{TRANSLATION('term-user-interface')} {TRANSLATION('opt-menu-language-text')}
{TRANSLATION('term-output')} {TRANSLATION('opt-menu-copyright-head-input')}

#####

{config['new']['copyright_head'] if config['new']['copyright_head'] else COPYRIGHT_HEAD}
{TRANSLATION('opt-menu-update-wrapfile').replace('$value', '')}
{TRANSLATION('term-input')}
{TRANSLATION('opt-menu-strict').replace('$value', '')}
{TRANSLATION('opt-menu-pretty').replace('$value', '')}

# {TRANSLATION('btn-edit')}